# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/bot.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ftarot/bot.proto\x12\x05tarot\x1a\x1bgoogle/protobuf/empty.proto\"L\n\rMessageAction\x12\r\n\x05title\x18\x01 \x01(\t\x12\r\n\x03url\x18\x02 \x01(\tH\x00\x12\x12\n\x08\x63\x61llback\x18\x03 \x01(\tH\x00\x42\t\n\x07payload\"\xa9\x02\n\x12SendMessageRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06\x62ot_id\x18\x02 \x01(\x03\x12%\n\x07\x61\x63tions\x18\x03 \x03(\x0b\x32\x14.tarot.MessageAction\x12\x15\n\rrecipient_ids\x18\x04 \x03(\x03\x12\x15\n\x08hook_tag\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\x16\n\tis_silent\x18\x06 \x01(\x08H\x01\x88\x01\x01\x12\x39\n\x08metadata\x18\x07 \x03(\x0b\x32\'.tarot.SendMessageRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0b\n\t_hook_tagB\x0c\n\n_is_silent\"\xb8\x01\n\x12TriggerHookRequest\x12\x10\n\x08hook_tag\x18\x01 \x01(\t\x12\x0e\n\x06\x62ot_id\x18\x02 \x01(\x03\x12\x14\n\x0crecipient_id\x18\x03 \x01(\x03\x12\x39\n\x08metadata\x18\x04 \x03(\x0b\x32\'.tarot.TriggerHookRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"L\n\x11MessageSentStatus\x12\x14\n\x0crecipient_id\x18\x01 \x01(\x03\x12!\n\x06status\x18\x02 \x01(\x0e\x32\x11.tarot.SentStatus\"A\n\x13SendMessageResponse\x12*\n\x08statuses\x18\x01 \x03(\x0b\x32\x18.tarot.MessageSentStatus\"d\n\rRefundRequest\x12\x0e\n\x06\x62ot_id\x18\x01 \x01(\x03\x12\x14\n\x0crecipient_id\x18\x02 \x01(\x03\x12\x16\n\x0etransaction_id\x18\x03 \x01(\t\x12\x15\n\rrefund_reason\x18\x04 \x01(\t*\xa6\x01\n\x11MessageActionType\x12#\n\x1fMESSAGE_ACTION_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17MESSAGE_ACTION_TYPE_URL\x10\x01\x12 \n\x1cMESSAGE_ACTION_TYPE_CALLBACK\x10\x02\x12-\n)MESSAGE_ACTION_TYPE_CALLBACK_PARAMETRIZED\x10\x03*t\n\nSentStatus\x12\x1b\n\x17SENT_STATUS_UNSPECIFIED\x10\x00\x12\x14\n\x10SENT_STATUS_SENT\x10\x01\x12\x15\n\x11SENT_STATUS_ERROR\x10\x02\x12\x1c\n\x18SENT_STATUS_USER_BLOCKED\x10\x03\x32\xdc\x01\n\nBotManager\x12\x46\n\x0bSendMessage\x12\x19.tarot.SendMessageRequest\x1a\x1a.tarot.SendMessageResponse\"\x00\x12\x45\n\x0eTriggerBotHook\x12\x19.tarot.TriggerHookRequest\x1a\x16.google.protobuf.Empty\"\x00\x12?\n\rPaymentRefund\x12\x14.tarot.RefundRequest\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.bot_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _SENDMESSAGEREQUEST_METADATAENTRY._options = None
  _SENDMESSAGEREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _TRIGGERHOOKREQUEST_METADATAENTRY._options = None
  _TRIGGERHOOKREQUEST_METADATAENTRY._serialized_options = b'8\001'
  _globals['_MESSAGEACTIONTYPE']._serialized_start=868
  _globals['_MESSAGEACTIONTYPE']._serialized_end=1034
  _globals['_SENTSTATUS']._serialized_start=1036
  _globals['_SENTSTATUS']._serialized_end=1152
  _globals['_MESSAGEACTION']._serialized_start=55
  _globals['_MESSAGEACTION']._serialized_end=131
  _globals['_SENDMESSAGEREQUEST']._serialized_start=134
  _globals['_SENDMESSAGEREQUEST']._serialized_end=431
  _globals['_SENDMESSAGEREQUEST_METADATAENTRY']._serialized_start=357
  _globals['_SENDMESSAGEREQUEST_METADATAENTRY']._serialized_end=404
  _globals['_TRIGGERHOOKREQUEST']._serialized_start=434
  _globals['_TRIGGERHOOKREQUEST']._serialized_end=618
  _globals['_TRIGGERHOOKREQUEST_METADATAENTRY']._serialized_start=357
  _globals['_TRIGGERHOOKREQUEST_METADATAENTRY']._serialized_end=404
  _globals['_MESSAGESENTSTATUS']._serialized_start=620
  _globals['_MESSAGESENTSTATUS']._serialized_end=696
  _globals['_SENDMESSAGERESPONSE']._serialized_start=698
  _globals['_SENDMESSAGERESPONSE']._serialized_end=763
  _globals['_REFUNDREQUEST']._serialized_start=765
  _globals['_REFUNDREQUEST']._serialized_end=865
  _globals['_BOTMANAGER']._serialized_start=1155
  _globals['_BOTMANAGER']._serialized_end=1375
# @@protoc_insertion_point(module_scope)
