# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/bots_master.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17tarot/bots_master.proto\x12\x05tarot\"\\\n\x0bPricingPlan\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\r\n\x05price\x18\x04 \x01(\x05\x12\x0f\n\x07\x63redits\x18\x05 \x01(\x05\"i\n\x0fRetentionConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x11\n\tfrequency\x18\x02 \x01(\t\x12\x0e\n\x06prompt\x18\x03 \x01(\t\x12\x15\n\x08\x62ot_hook\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_bot_hook\"\x86\x01\n\x0eTarotBotConfig\x12\x15\n\rspread_prompt\x18\x01 \x01(\t\x12)\n\rpricing_plans\x18\x02 \x03(\x0b\x32\x12.tarot.PricingPlan\x12\x1d\n\x10\x64\x65\x66\x61ult_language\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x13\n\x11_default_language\"\xdf\x01\n\x03\x42ot\x12\n\n\x02id\x18\x01 \x01(\x03\x12\r\n\x05token\x18\x02 \x01(\t\x12\x1e\n\x05group\x18\x03 \x01(\x0e\x32\x0f.tarot.BotGroup\x12$\n\x08provider\x18\x04 \x01(\x0e\x32\x12.tarot.BotProvider\x12\x0c\n\x04name\x18\x05 \x01(\t\x12-\n\x0ctarot_config\x18\x06 \x01(\x0b\x32\x15.tarot.TarotBotConfigH\x00\x12\x30\n\x10retention_config\x18\x07 \x01(\x0b\x32\x16.tarot.RetentionConfigB\x08\n\x06\x63onfig\"[\n\x13RetrieveBotsRequest\x12\x1e\n\x05group\x18\x01 \x01(\x0e\x32\x0f.tarot.BotGroup\x12$\n\x08provider\x18\x02 \x01(\x0e\x32\x12.tarot.BotProvider\"0\n\x14RetrieveBotsResponse\x12\x18\n\x04\x62ots\x18\x01 \x03(\x0b\x32\n.tarot.Bot\" \n\x12RetrieveBotRequest\x12\n\n\x02id\x18\x01 \x01(\x03*:\n\x08\x42otGroup\x12\x19\n\x15\x42OT_GROUP_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x42OT_GROUP_TAROT\x10\x01*v\n\x0b\x42otProvider\x12\x1c\n\x18\x42OT_PROVIDER_UNSPECIFIED\x10\x00\x12\x19\n\x15\x42OT_PROVIDER_TELEGRAM\x10\x01\x12\x16\n\x12\x42OT_PROVIDER_SLACK\x10\x02\x12\x16\n\x12\x42OT_PROVIDER_VIBER\x10\x03\x32\x8b\x01\n\nBotsMaster\x12G\n\x0cRetrieveBots\x12\x1a.tarot.RetrieveBotsRequest\x1a\x1b.tarot.RetrieveBotsResponse\x12\x34\n\x0bRetrieveBot\x12\x19.tarot.RetrieveBotRequest\x1a\n.tarot.Botb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.bots_master_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BOTGROUP']._serialized_start=775
  _globals['_BOTGROUP']._serialized_end=833
  _globals['_BOTPROVIDER']._serialized_start=835
  _globals['_BOTPROVIDER']._serialized_end=953
  _globals['_PRICINGPLAN']._serialized_start=34
  _globals['_PRICINGPLAN']._serialized_end=126
  _globals['_RETENTIONCONFIG']._serialized_start=128
  _globals['_RETENTIONCONFIG']._serialized_end=233
  _globals['_TAROTBOTCONFIG']._serialized_start=236
  _globals['_TAROTBOTCONFIG']._serialized_end=370
  _globals['_BOT']._serialized_start=373
  _globals['_BOT']._serialized_end=596
  _globals['_RETRIEVEBOTSREQUEST']._serialized_start=598
  _globals['_RETRIEVEBOTSREQUEST']._serialized_end=689
  _globals['_RETRIEVEBOTSRESPONSE']._serialized_start=691
  _globals['_RETRIEVEBOTSRESPONSE']._serialized_end=739
  _globals['_RETRIEVEBOTREQUEST']._serialized_start=741
  _globals['_RETRIEVEBOTREQUEST']._serialized_end=773
  _globals['_BOTSMASTER']._serialized_start=956
  _globals['_BOTSMASTER']._serialized_end=1095
# @@protoc_insertion_point(module_scope)
